==> struts-6.7.0-all.zip: struts-6.7.0/src/plugins/tiles/src/main/java/org/apache/tiles/request/servlet/extractor/InitParameterExtractor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tiles.request.servlet.extractor;

import org.apache.tiles.request.attribute.HasKeys;

import javax.servlet.ServletContext;
import java.util.Enumeration;

/**
 * Extract initialization parameters from the servlet context.
 */
public class InitParameterExtractor implements HasKeys<String> {

    /**
     * The servlet context.
     */
    private final ServletContext context;

    /**
     * Constructor.
     *
     * @param context The servlet context.
     */
    public InitParameterExtractor(ServletContext context) {
        this.context = context;
    }

    @Override
    public Enumeration<String> getKeys() {
        return context.getInitParameterNames();
    }

    @Override
    public String getValue(String key) {
        return context.getInitParameter(key);
    }

}

==> struts-7.0.0-all.zip: struts-7.0.0/src/plugins/tiles/src/main/java/org/apache/tiles/request/servlet/extractor/InitParameterExtractor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tiles.request.servlet.extractor;

import org.apache.tiles.request.attribute.HasKeys;

import jakarta.servlet.ServletContext;
import java.util.Enumeration;

/**
 * Extract initialization parameters from the servlet context.
 */
public class InitParameterExtractor implements HasKeys<String> {

    /**
     * The servlet context.
     */
    private final ServletContext context;

    /**
     * Constructor.
     *
     * @param context The servlet context.
     */
    public InitParameterExtractor(ServletContext context) {
        this.context = context;
    }

    @Override
    public Enumeration<String> getKeys() {
        return context.getInitParameterNames();
    }

    @Override
    public String getValue(String key) {
        return context.getInitParameter(key);
    }

}
